@@ -36,8 +36,11 @@ public:
 private:
     Q_DECLARE_PRIVATE_D(Event::d, GUIActivateEvent)
 #if KPARTS_BUILD_DEPRECATED_SINCE(5, 79)
+    QT_WARNING_PUSH
+    QT_WARNING_DISABLE_CLANG("-Wunused-private-field")
     // Unused, kept for ABI compatibility
     const void *__kparts_d_do_not_use;
+    QT_WARNING_POP
 #endif
 };
 
