@@ -77,8 +77,8 @@ private:
 class KParts::StatusBarExtensionPrivate
 {
 public:
-    StatusBarExtensionPrivate(StatusBarExtension *q)
-        : q(q)
+    StatusBarExtensionPrivate(StatusBarExtension *qq)
+        : q(qq)
         , m_statusBar(nullptr)
         , m_activated(true)
     {
@@ -183,7 +183,7 @@ void StatusBarExtension::removeStatusBarItem(QWidget *widget)
 {
     QStatusBar *sb = statusBar();
     QList<StatusBarItem>::iterator it = d->m_statusBarItems.begin();
-    for (; it != d->m_statusBarItems.end(); ++it)
+    for (; it != d->m_statusBarItems.end(); ++it) {
         if ((*it).widget() == widget) {
             if (sb) {
                 (*it).ensureItemHidden(sb);
@@ -191,6 +191,9 @@ void StatusBarExtension::removeStatusBarItem(QWidget *widget)
             d->m_statusBarItems.erase(it);
             return;
         }
+    }
 
     qCWarning(KPARTSLOG) << "StatusBarExtension::removeStatusBarItem. Widget not found :" << widget;
 }
+
+#include "moc_statusbarextension.cpp"
